import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:nova_utils/update/update_utils.dart';

import 'kv_utils.dart';

class NovaUtils {
  static const MethodChannel _channel = const MethodChannel('nova_utils');

  //IOS 获取钥匙链的值
  static Future<Map<String, String>> getKeyChainValue(
      List<String> paramsName) async {
    if (Platform.isIOS) {
      final Map<String, String> value = new Map<String, String>.from(
          await _channel.invokeMethod('getKeyChainValue', paramsName));
      return value;
    } else {
      return null;
    }
  }

  //IOS 设置钥匙链的值
  static Future<bool> setKeyChanValue(Map<String, String> params) async {
    if (Platform.isIOS) {
      final bool value =
          await _channel.invokeMethod('setKeyChainValue', params);
      return value;
    } else {
      return false;
    }
  }

  //获取单个kv后台配置
  static Future<String> getConfigParams(String key) async {
    //如果是第一次启动，则从网络获取keValue
    if (!OnlineConfigUtils.success) {
      await OnlineConfigUtils.getInstance().init();
    }
    return OnlineConfigUtils.getInstance().getConfigParams(key);
  }

  static Future<void> checkUpdate(BuildContext context) async {
    //如果没有加载过远程配置则请求一次
      if (!OnlineConfigUtils.success) {
        await OnlineConfigUtils.getInstance().init();
      }
      UpdateUtils.checkUpdate(context);
  }

  static Future<void> launchMarket({String iosUrl}) async {
    if (Platform.isIOS) {
      await _channel.invokeMethod('launchMarket', iosUrl);
    } else {
      await _channel.invokeMethod('launchMarket');
    }
  }
}
