import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:nova_utils/update/update_utils.dart';

import '../nova_utils.dart';
import 'android_update_config.dart';
import 'ios_update_config.dart';

class UpdateDialogUtils {
  static final TextStyle dialogTitleTextStyle = TextStyle(fontSize: 18);
  static final TextStyle dialogButtonTextStyle = TextStyle(color:Colors.blue,fontSize: 14);
  static final TextStyle dialogTextStyle = TextStyle(fontSize: 15);

  static Future<void> showIosUpDateDialog(
      BuildContext context, IosUpdateConfig config) async {
    //iOS
    showDialog<void>(
        context: context,
        barrierDismissible: false,
        builder: (BuildContext context) {
          return CupertinoAlertDialog(
            title: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Text(config.up_title, style: dialogButtonTextStyle)
              ],
            ),
            content: getIosContent(config),
            actions: <Widget>[
              config.up_strategy_force == "true"
                  ? null
                  : CupertinoDialogAction(
                      child: Text("跳过此版本", style: dialogButtonTextStyle),
                      onPressed: () {
                        UpdateUtils.addSkipUpdate(config.up_new_version);
                        Navigator.of(context).pop();
                      },
                    ),
              FlatButton(
                child: config.up_strategy_force != "true"
                    ? Text('稍后再说', style: dialogButtonTextStyle)
                    : Text('退出', style: dialogButtonTextStyle),
                onPressed: () {
                  Navigator.of(context).pop();
                  if (config.up_strategy_force == "true") {
                    quitApp();
                  }
                },
              ),
              CupertinoDialogAction(
                child:
                    Text(config.up_confirm_text, style: dialogButtonTextStyle),
                onPressed: () {
                  if (config.up_strategy_force != "true") {
                    Navigator.of(context).pop();
                  }
                  NovaUtils.launchMarket(iosUrl: config.up_targeturl);
                },
              )
            ],
          );
        });
  }

  static Widget getIosContent(IosUpdateConfig config) {
    var slits = config.up_content.split(r"\n");
    print(slits.length);
    StringBuffer sb = StringBuffer();
    for (var value in slits) {
      sb.write(value);
      sb.write("\n");
    }
    return Text(
      sb.toString(),
      style: dialogTextStyle,
    );
  }

  static Widget getContent(AndroidUpdateConfig config) {
    var slits = config.releaseNote.split(r"\n");
    print(slits.length);
    StringBuffer sb = StringBuffer();
    for (var value in slits) {
      sb.write(value);
      sb.write("\n");
    }
    return Text(
      sb.toString(),
      style: dialogTextStyle,
    );
  }

  static Future showAndroidDialog(
      BuildContext context, AndroidUpdateConfig config) async {
    print("shouldForceUpdate=${config.forceUpdate}");
    print("minupdatecode=${config.updateVersionMin}");
    showDialog<void>(
        context: context,
        barrierDismissible: false,
        builder: (BuildContext context) {
          return WillPopScope(
            onWillPop: () {
//              if (!config.forceUpdate) {
//                Navigator.of(context).pop();
//              }
              return;
            },
            child: AlertDialog(
              title: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[Text("版本更新", style: dialogTitleTextStyle)],
              ),
              content: getContent(config),
              actions: <Widget>[
                !config.forceUpdate
                    ? FlatButton(
                        child: Text('跳过此版本', style: dialogButtonTextStyle),
                        onPressed: () {
                          Navigator.of(context).pop();
                          UpdateUtils.addSkipUpdate(config.updateVersionName);
                        },
                      )
                    : null,
                FlatButton(
                  child: !config.forceUpdate
                      ? Text('稍后再说', style: dialogButtonTextStyle)
                      : Text('退出', style: dialogButtonTextStyle),
                  onPressed: () {
                    Navigator.of(context).pop();
                    if (config.forceUpdate) {
                      quitApp();
                    }
                  },
                ),
                FlatButton(
                  child: Text('更新', style: dialogButtonTextStyle),
                  onPressed: () {
                    if (!config.forceUpdate) {
                      Navigator.of(context).pop();
                    }
                    NovaUtils.launchMarket();
                  },
                )
              ],
            ),
          );
        });
  }

  static void quitApp() async {
    await SystemChannels.platform.invokeMethod('SystemNavigator.pop');
  }
}
