import 'dart:io';
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../nova_utils.dart';
import 'android_update.dart';
import 'ios_update.dart';

abstract class UpdateCase {
  Future checkUpdate(BuildContext context);
}

const String update_firstStart = "update_firstStart";
const String skipList = "skilList";

class UpdateUtils {
  static void checkUpdate(BuildContext context) async {
    if (Platform.isAndroid) {
      await AndroidUpdateDelegate().checkUpdate(context);
    } else if (Platform.isIOS) {
      IosUpdateDelegate().checkUpdate(context);
    }
  }

  static Future<List<String>> get skipUpdateList async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    return prefs.getStringList(skipList);
  }

  static Future<bool> addSkipUpdate(String versionName) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var stringList = prefs.getStringList(skipList);
    if (stringList == null) {
      stringList = [];
    }
    stringList.add(versionName);
    return await prefs.setStringList(skipList, stringList);
  }

  static Future<bool> isInSkipList(String versionName) async {
    List<String> skipList = await UpdateUtils.skipUpdateList;
    if (skipList == null) {
      return false;
    }
    return skipList.contains(versionName);
  }
}
